@@ -1,31 +1,39 @@
+use strict;
+use warnings;
+
 package Net::Trac;
 use Moose;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.03';
+
+use Net::Trac::Connection;
+use Net::Trac::Ticket;
+use Net::Trac::TicketHistory;
+use Net::Trac::TicketAttachment;
+use Net::Trac::TicketSearch;
 
 =head1 NAME
 
-Net::Trac
+Net::Trac - Interact with a remote Trac instance
 
 =head1 SYNOPSIS
 
- my $trac = Net::Trac::Connection->new(
-     url      => 'http://trac.someproject.org',
-     user     => 'hiro',
-     password => 'yatta'
- );
- 
- 
- my $ticket = Net::Trac::Ticket->new( connection => $trac);
- my $id = $ticket->create(summary => 'This product has only a moose, not a pony');
- 
- my $other_ticket = Net::Trac::Ticket->new( connection => $trac);
- $other_ticket->load($id);
- print $other_ticket->summary;
- 
- $ticket->update( summary => 'This project has no pony');
+    use Net::Trac;
 
+    my $trac = Net::Trac::Connection->new(
+        url      => 'http://trac.someproject.org',
+        user     => 'hiro',
+        password => 'yatta'
+    );
 
+    my $ticket = Net::Trac::Ticket->new( connection => $trac );
+    my $id = $ticket->create(summary => 'This product has only a moose, not a pony');
+
+    my $other_ticket = Net::Trac::Ticket->new( connection => $trac );
+    $other_ticket->load($id);
+    print $other_ticket->summary, "\n";
+
+    $ticket->update( summary => 'This project has no pony' );
 
 =head1 DESCRIPTION
 
@@ -45,19 +53,23 @@ appreciated.
 =head1 BUGS
 
 This module currently only deals with Trac's bug tracking system.
+
 This module is woefully incomplete.
-This module's error handling isn't what it should be
+
+This module's error handling isn't what it should be.
+
 There are more.
 
 Please send bug reports and patches to bug-net-trac@rt.cpan.org
 
 =head1 AUTHOR
 
-Jesse Vincent <jesse@bestpractical.com>
+Jesse Vincent <jesse@bestpractical.com>, Thomas Sibley <trs@bestpractical.com>
 
 =head1 LICENSE
 
-Copyright 2008 Best Practical Solutions.
+Copyright 2008-2009 Best Practical Solutions.
+
 This package is licensed under the same terms as Perl 5.8.8.
 
 =cut
